==> gnista_library-1.3.7-py3-none-any.whl: data_point_client/api/data_point/data_point_create_chiller_samples.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.problem_details import ProblemDetails
from ...types import Response


def _get_kwargs(
    tenant_name: Optional[str],
    consumption_id: str,
    production_id: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/DataPoint/tenant/{tenantName}/chiller/{consumptionId}/{productionId}".format(
        client.base_url, tenantName=tenant_name, consumptionId=consumption_id, productionId=production_id
    )

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, ProblemDetails]]:
    if response.status_code == 202:
        response_202 = None

        return response_202
    if response.status_code == 400:
        response_400 = ProblemDetails.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = ProblemDetails.from_dict(response.json())

        return response_401
    if response.status_code == 403:
        response_403 = ProblemDetails.from_dict(response.json())

        return response_403
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[Any, ProblemDetails]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    tenant_name: Optional[str],
    consumption_id: str,
    production_id: str,
    *,
    client: Client,
) -> Response[Union[Any, ProblemDetails]]:
    kwargs = _get_kwargs(
        tenant_name=tenant_name,
        consumption_id=consumption_id,
        production_id=production_id,
        client=client,
    )

    response = httpx.post(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    tenant_name: Optional[str],
    consumption_id: str,
    production_id: str,
    *,
    client: Client,
) -> Optional[Union[Any, ProblemDetails]]:
    """ """

    return sync_detailed(
        tenant_name=tenant_name,
        consumption_id=consumption_id,
        production_id=production_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    tenant_name: Optional[str],
    consumption_id: str,
    production_id: str,
    *,
    client: Client,
) -> Response[Union[Any, ProblemDetails]]:
    kwargs = _get_kwargs(
        tenant_name=tenant_name,
        consumption_id=consumption_id,
        production_id=production_id,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    tenant_name: Optional[str],
    consumption_id: str,
    production_id: str,
    *,
    client: Client,
) -> Optional[Union[Any, ProblemDetails]]:
    """ """

    return (
        await asyncio_detailed(
            tenant_name=tenant_name,
            consumption_id=consumption_id,
            production_id=production_id,
            client=client,
        )
    ).parsed

==> gnista_library-1.4.0-py3-none-any.whl: data_point_client/api/data_point/data_point_create_chiller_samples.py <==
from typing import Any, Dict, Optional, Union, cast

import httpx

from ...client import Client
from ...models.problem_details import ProblemDetails
from ...types import Response


def _get_kwargs(
    tenant_name: Optional[str],
    consumption_id: str,
    production_id: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/DataPoint/tenant/{tenantName}/chiller/{consumptionId}/{productionId}".format(
        client.base_url, tenantName=tenant_name, consumptionId=consumption_id, productionId=production_id
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, ProblemDetails]]:
    if response.status_code == 202:
        response_202 = cast(Any, None)
        return response_202
    if response.status_code == 400:
        response_400 = ProblemDetails.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = ProblemDetails.from_dict(response.json())

        return response_401
    if response.status_code == 403:
        response_403 = ProblemDetails.from_dict(response.json())

        return response_403
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[Any, ProblemDetails]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    tenant_name: Optional[str],
    consumption_id: str,
    production_id: str,
    *,
    client: Client,
) -> Response[Union[Any, ProblemDetails]]:
    """
    Args:
        tenant_name (Optional[str]):
        consumption_id (str):
        production_id (str):

    Returns:
        Response[Union[Any, ProblemDetails]]
    """

    kwargs = _get_kwargs(
        tenant_name=tenant_name,
        consumption_id=consumption_id,
        production_id=production_id,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    tenant_name: Optional[str],
    consumption_id: str,
    production_id: str,
    *,
    client: Client,
) -> Optional[Union[Any, ProblemDetails]]:
    """
    Args:
        tenant_name (Optional[str]):
        consumption_id (str):
        production_id (str):

    Returns:
        Response[Union[Any, ProblemDetails]]
    """

    return sync_detailed(
        tenant_name=tenant_name,
        consumption_id=consumption_id,
        production_id=production_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    tenant_name: Optional[str],
    consumption_id: str,
    production_id: str,
    *,
    client: Client,
) -> Response[Union[Any, ProblemDetails]]:
    """
    Args:
        tenant_name (Optional[str]):
        consumption_id (str):
        production_id (str):

    Returns:
        Response[Union[Any, ProblemDetails]]
    """

    kwargs = _get_kwargs(
        tenant_name=tenant_name,
        consumption_id=consumption_id,
        production_id=production_id,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    tenant_name: Optional[str],
    consumption_id: str,
    production_id: str,
    *,
    client: Client,
) -> Optional[Union[Any, ProblemDetails]]:
    """
    Args:
        tenant_name (Optional[str]):
        consumption_id (str):
        production_id (str):

    Returns:
        Response[Union[Any, ProblemDetails]]
    """

    return (
        await asyncio_detailed(
            tenant_name=tenant_name,
            consumption_id=consumption_id,
            production_id=production_id,
            client=client,
        )
    ).parsed
